%define anolis_release 4
# Unset -s on python shebang - ensure that extensions installed with pip
# to user locations are seen and properly loaded
%undefine _py3_shebang_s

Name:           python-jupyter-client
Version:        7.4.9
Release:        %{anolis_release}%{?dist}
Summary:        Jupyter protocol implementation and client libraries

License:        BSD
URL:            https://jupyter.org
Source0:        %{pypi_source jupyter_client}

BuildArch:      noarch

BuildRequires:  python3-devel

%bcond_without doc
%bcond_without tests

%if %{with tests}
# The zmq tests are split in RPM only, the dependency is not tracked on Python level:
BuildRequires:  python3-zmq-tests
%endif

%description
This package contains the reference implementation of the Jupyter protocol.
It also provides client and kernel management APIs for working with kernels.

It also provides the `jupyter kernelspec` entrypoint for installing kernelspecs
for use with Jupyter frontends.

%package -n     python3-jupyter-client
Summary:        %{summary}

# It fallbacks to ifconfig without this, and ifconfig is deprecated
Recommends:     python3-netifaces

%description -n python3-jupyter-client
This package contains the reference implementation of the Jupyter protocol.
It also provides client and kernel management APIs for working with kernels.

It also provides the `jupyter kernelspec` entrypoint for installing kernelspecs
for use with Jupyter frontends.

%if %{with doc}
%package -n python3-jupyter-client-doc
Summary:        Documentation of the Jupyter protocol reference implementation
Requires:       python3-jupyter-client = %{version}-%{release}

%description -n python3-jupyter-client-doc
Documentation of the reference implementation of the Jupyter protocol
%endif

%prep
%autosetup -p1 -n jupyter_client-%{version}
# Drop dependencies on coverage, linters etc.
sed -Ei '/\b(codecov|coverage|mypy|pre-commit|pytest-cov)\b/d' pyproject.toml
# Delete mypy config options
sed -i '/check_untyped/Q' pyproject.toml


%if %{with doc}
# Use local objects.inv for intersphinx:
sed -i "s|\(('http://ipython.readthedocs.io/en/stable/', \)None)|\1'/usr/share/doc/python3-ipython-doc/html/objects.inv')|" docs/conf.py
%endif


%generate_buildrequires
%pyproject_buildrequires %{?with_tests:-x test} %{?with_doc:-x doc}


%build
%pyproject_wheel

%if %{with doc}
PYTHONPATH=build/lib/ sphinx-build-3 docs html
# remove the sphinx-build leftovers
rm -r html/.{doctrees,buildinfo}
%endif


%install
%pyproject_install
%pyproject_save_files jupyter_client

echo "%%{python3_sitelib}/jupyter_client-%{version}.dist-info/licenses/COPYING.md" >> %{pyproject_files}

%if %{with tests}
%check
# The two tests testing signals for kernels are flaky because
# if it takes the kernel more than one second to respond, it's killed.
# The tests work fine outside mock.
%pytest -v -k "not test_signal_kernel_subprocesses and not test_async_signal_kernel_subprocesses"
%endif


%global _docdir_fmt %{name}

%files -n python3-jupyter-client -f %{pyproject_files}
%{_bindir}/jupyter-kernel
%{_bindir}/jupyter-kernelspec
%{_bindir}/jupyter-run

%if %{with doc}
%files -n python3-jupyter-client-doc
%doc README.md
%doc html
%endif

%changelog
* Wed Mar 27 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 7.4.9-4
- Build with docs and tests

* Wed Mar 27 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 7.4.9-3
- Rebuild with python3.11 without docs and tests

* Tue May 09 2023 Funda Wang <fundawang@yeah.net> - 7.4.9-2
- Build with docs and tests

* Wed May 03 2023 Funda Wang <fundawang@yeah.net> - 7.4.9-1
- Import package for anolis 23
